@@ -13,7 +13,7 @@ var fs = require('fs-extra')
 
 exports.create= function(path){
     console.log("init project");
-    var dirs=["app","config","public","sass","ssl","loggers"];
+    var dirs=["app","config"];
     dirs.map(function(dir){
         console.log(dir);
         fs.exists(process.cwd()+'/'+dir, function(exists) { 
