@@ -45,15 +45,25 @@ exports.serve = function (nylon_path, port) {
 
         cluster.fork();
         cluster.on('exit', (worker, code, signal) => {
-            cluster.fork();
-            logger.info('worker ' + worker.process.pid + ' died');
+            console.log("code::"+code);
+            console.log("signal::"+signal);
+            if(code!="^C" || code!=0){
+                cluster.fork();
+                logger.info('worker ' + worker.process.pid + ' died');
+            }
+           
         });
+      //  cluster.on('online', (worker) => {
+            console.log(process.cwd());
+            watcher.addWatcher(process.cwd() + '/app');
+            watcher.addWatcher(process.cwd() + '/config');
+           // watcher.addWatcher(process.cwd() + '/ssl');
+            watcher.addWatcher(nylon.nylon_path + '/java/libs');
+            watcher.addWatcher(nylon.nylon_path + '/java/nylon-report/dist');
+            watcher.addWatcher(nylon.nylon_path + '/java/nylon-utility/dist');
+            watcher.addWatcher(nylon.nylon_path + '/lib');
+     //   });
 
-        watcher.addWatcher(process.cwd() + '/app');
-        watcher.addWatcher(process.cwd() + '/config');
-       // watcher.addWatcher(process.cwd() + '/ssl');
-        watcher.addWatcher(nylon.nylon_path + '/java');
-        watcher.addWatcher(nylon.nylon_path + '/lib');
 
     } else {
 
